@@ -24,10 +24,10 @@ from mutwo.utilities import tools
 
 __all__ = (
     "SequentialEventToQuantizedAbjadContainerConverter",
-    "ComplexSequentialEventToQuantizedAbjadContainerConverter",
-    "ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter",
-    "FastSequentialEventToQuantizedAbjadContainerConverter",
-    "FastSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter",
+    "NauertSequentialEventToQuantizedAbjadContainerConverter",
+    "NauertSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter",
+    "RMakersSequentialEventToQuantizedAbjadContainerConverter",
+    "RMakersSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter",
 )
 
 
@@ -81,14 +81,11 @@ class SequentialEventToQuantizedAbjadContainerConverter(converters_abc.Converter
     @abc.abstractmethod
     def convert(
         self, sequential_event_to_convert: events.basic.SequentialEvent
-    ) -> typing.Tuple[
-        abjad.Container,
-        typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...],
-    ]:
+    ) -> tuple[abjad.Container, tuple[tuple[tuple[int, ...], ...], ...]]:
         raise NotImplementedError
 
 
-class ComplexSequentialEventToQuantizedAbjadContainerConverter(
+class NauertSequentialEventToQuantizedAbjadContainerConverter(
     SequentialEventToQuantizedAbjadContainerConverter
 ):
     """Quantize :class:`~mutwo.events.basic.SequentialEvent` objects via :mod:`abjadext.nauert`.
@@ -114,9 +111,9 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
         to better represent metrical structures within bars. If no optimizer is desired
         this argument can be set to ``None``.
 
-    Unlike :class:`FastSequentialEventToQuantizedAbjadContainerConverter` this converter
+    Unlike :class:`RMakersSequentialEventToQuantizedAbjadContainerConverter` this converter
     supports nested tuplets and ties across tuplets. But this converter is much slower
-    than the :class:`FastSequentialEventToQuantizedAbjadContainerConverter`. Because the
+    than the :class:`RMakersSequentialEventToQuantizedAbjadContainerConverter`. Because the
     converter depends on the abjad extension `nauert` its quality is dependent on the
     inner mechanism of the used package. Because the quantization made by the `nauert`
     package can be somewhat indeterministic a lot of tweaking may be necessary for
@@ -160,7 +157,7 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
         self._duration_unit = duration_unit
         self._attack_point_optimizer = attack_point_optimizer
         self._q_schema = (
-            ComplexSequentialEventToQuantizedAbjadContainerConverter._make_q_schema(
+            NauertSequentialEventToQuantizedAbjadContainerConverter._make_q_schema(
                 self._time_signatures, search_tree
             )
         )
@@ -185,16 +182,14 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
 
     @staticmethod
     def _process_abjad_leaf(
-        indices: typing.List[int],
+        indices: list[int],
         abjad_leaf: abjad.Leaf,
-        related_abjad_leaves_per_simple_event: typing.List[
-            typing.List[typing.Tuple[int, ...]]
-        ],
+        related_abjad_leaves_per_simple_event: list[list[tuple[int, ...]]],
         q_event_sequence: nauert.QEventSequence,
         has_tie: bool,
         index_of_previous_q_event: int,
-    ) -> typing.Tuple[bool, int]:
-        q_event = ComplexSequentialEventToQuantizedAbjadContainerConverter._get_respective_q_event_from_abjad_leaf(
+    ) -> tuple[bool, int]:
+        q_event = NauertSequentialEventToQuantizedAbjadContainerConverter._get_respective_q_event_from_abjad_leaf(
             abjad_leaf
         )
 
@@ -216,15 +211,13 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
 
     @staticmethod
     def _process_tuplet(
-        indices: typing.List[int],
+        indices: list[int],
         tuplet: abjad.Tuplet,
-        related_abjad_leaves_per_simple_event: typing.List[
-            typing.List[typing.Tuple[int, ...]]
-        ],
+        related_abjad_leaves_per_simple_event: list[list[tuple[int, ...]]],
         q_event_sequence: nauert.QEventSequence,
         has_tie: bool,
         index_of_previous_q_event: int,
-    ) -> typing.Tuple[bool, int]:
+    ) -> tuple[bool, int]:
         for (
             nth_abjad_leaf_or_tuplet,
             abjad_leaf_or_tuplet,
@@ -232,7 +225,7 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
             (
                 has_tie,
                 index_of_previous_q_event,
-            ) = ComplexSequentialEventToQuantizedAbjadContainerConverter._process_abjad_leaf_or_tuplet(
+            ) = NauertSequentialEventToQuantizedAbjadContainerConverter._process_abjad_leaf_or_tuplet(
                 indices + [nth_abjad_leaf_or_tuplet],
                 abjad_leaf_or_tuplet,
                 related_abjad_leaves_per_simple_event,
@@ -245,27 +238,27 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
 
     @staticmethod
     def _process_abjad_leaf_or_tuplet(
-        indices: typing.List[int],
+        indices: list[int],
         abjad_leaf_or_tuplet: typing.Union[abjad.Tuplet, abjad.Leaf],
-        related_abjad_leaves_per_simple_event: typing.List[
-            typing.List[typing.Tuple[int, ...]]
-        ],
+        related_abjad_leaves_per_simple_event: list[list[tuple[int, ...]]],
         q_event_sequence: nauert.QEventSequence,
         has_tie: bool,
         index_of_previous_q_event: int,
-    ) -> typing.Tuple[bool, int]:
+    ) -> tuple[bool, int]:
         if isinstance(abjad_leaf_or_tuplet, abjad.Tuplet):
-            return ComplexSequentialEventToQuantizedAbjadContainerConverter._process_tuplet(
-                indices,
-                abjad_leaf_or_tuplet,
-                related_abjad_leaves_per_simple_event,
-                q_event_sequence,
-                has_tie,
-                index_of_previous_q_event,
+            return (
+                NauertSequentialEventToQuantizedAbjadContainerConverter._process_tuplet(
+                    indices,
+                    abjad_leaf_or_tuplet,
+                    related_abjad_leaves_per_simple_event,
+                    q_event_sequence,
+                    has_tie,
+                    index_of_previous_q_event,
+                )
             )
 
         else:
-            return ComplexSequentialEventToQuantizedAbjadContainerConverter._process_abjad_leaf(
+            return NauertSequentialEventToQuantizedAbjadContainerConverter._process_abjad_leaf(
                 indices,
                 abjad_leaf_or_tuplet,
                 related_abjad_leaves_per_simple_event,
@@ -279,18 +272,18 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
         sequential_event: events.basic.SequentialEvent,
         q_event_sequence: nauert.QEventSequence,
         quanitisized_abjad_leaves: abjad.Voice,
-    ) -> typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...,]:
+    ) -> tuple[tuple[tuple[int, ...], ...], ...,]:
         has_tie = False
         index_of_previous_q_event: int = 0
-        related_abjad_leaves_per_simple_event: typing.List[
-            typing.List[typing.Tuple[int, ...]]
-        ] = [[] for _ in sequential_event]
+        related_abjad_leaves_per_simple_event: list[list[tuple[int, ...]]] = [
+            [] for _ in sequential_event
+        ]
         for nth_bar, bar in enumerate(quanitisized_abjad_leaves):
             for nth_abjad_leaf_or_tuplet, abjad_leaf_or_tuplet in enumerate(bar):
                 (
                     has_tie,
                     index_of_previous_q_event,
-                ) = ComplexSequentialEventToQuantizedAbjadContainerConverter._process_abjad_leaf_or_tuplet(
+                ) = NauertSequentialEventToQuantizedAbjadContainerConverter._process_abjad_leaf_or_tuplet(
                     [nth_bar, nth_abjad_leaf_or_tuplet],
                     abjad_leaf_or_tuplet,
                     related_abjad_leaves_per_simple_event,
@@ -306,7 +299,7 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
 
     @staticmethod
     def _make_q_schema(
-        time_signatures: typing.Tuple[abjad.TimeSignature, ...],
+        time_signatures: tuple[abjad.TimeSignature, ...],
         search_tree: typing.Optional[nauert.SearchTree],
     ) -> nauert.QSchema:
         formated_time_signatures = []
@@ -368,10 +361,7 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
 
     def convert(
         self, sequential_event_to_convert: events.basic.SequentialEvent
-    ) -> typing.Tuple[
-        abjad.Container,
-        typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...],
-    ]:
+    ) -> tuple[abjad.Container, tuple[tuple[tuple[int, ...], ...], ...],]:
         q_event_sequence = self._sequential_event_to_q_event_sequence(
             sequential_event_to_convert
         )
@@ -379,7 +369,7 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
             q_event_sequence
         )
 
-        related_abjad_leaves_per_simple_event = ComplexSequentialEventToQuantizedAbjadContainerConverter._make_related_abjad_leaves_per_simple_event(
+        related_abjad_leaves_per_simple_event = NauertSequentialEventToQuantizedAbjadContainerConverter._make_related_abjad_leaves_per_simple_event(
             sequential_event_to_convert, q_event_sequence, quanitisized_abjad_leaves
         )
         return (
@@ -388,10 +378,10 @@ class ComplexSequentialEventToQuantizedAbjadContainerConverter(
         )
 
 
-class FastSequentialEventToQuantizedAbjadContainerConverter(
+class RMakersSequentialEventToQuantizedAbjadContainerConverter(
     SequentialEventToQuantizedAbjadContainerConverter
 ):
-    """Quantize :class:`~mutwo.events.basic.SequentialEvent` object via abjad rmakers
+    """Quantize :class:`~mutwo.events.basic.SequentialEvent` object via :mod:`abjadext.rmakers`.
 
     :param time_signatures: Set time signatures to divide the quantized abjad data
         in desired bar sizes. If the converted
@@ -405,12 +395,12 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
         has been defined, Mutwo will assume a constant tempo of 1/4 = 120 BPM.
 
     This method is significantly faster than the
-    :class:`ComplexSequentialEventToQuantizedAbjadContainerConverter`. But it also
+    :class:`NauertSequentialEventToQuantizedAbjadContainerConverter`. But it also
     has several known limitations:
 
-        1. :class:`FastSequentialEventToQuantizedAbjadContainerConverter` doesn't
+        1. :class:`RMakersSequentialEventToQuantizedAbjadContainerConverter` doesn't
            support nested tuplets.
-        2. :class:`FastSequentialEventToQuantizedAbjadContainerConverter` doesn't
+        2. :class:`RMakersSequentialEventToQuantizedAbjadContainerConverter` doesn't
            support ties across tuplets with different prolation (or across tuplets
            and not-tuplet notation). If ties are desired the user has to build them
            manually before passing the :class:`~mutwo.events.basic.SequentialEvent`
@@ -446,7 +436,7 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
     def _add_explicit_beams(
         bar: abjad.Container, meter: abjad.Meter, global_offset: abjad.Offset
     ) -> None:
-        offset_inventory = FastSequentialEventToQuantizedAbjadContainerConverter._find_offset_inventory(
+        offset_inventory = RMakersSequentialEventToQuantizedAbjadContainerConverter._find_offset_inventory(
             meter
         )
         leaf_offsets = []
@@ -568,18 +558,16 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
         return notes
 
     def _concatenate_adjacent_tuplets_for_one_bar(self, bar: abjad.Container):
-        tuplet_indices = (
-            FastSequentialEventToQuantizedAbjadContainerConverter._find_tuplet_indices(
-                bar
-            )
+        tuplet_indices = RMakersSequentialEventToQuantizedAbjadContainerConverter._find_tuplet_indices(
+            bar
         )
         if tuplet_indices:
-            grouped_tuplet_indices = FastSequentialEventToQuantizedAbjadContainerConverter._group_tuplet_indices(
+            grouped_tuplet_indices = RMakersSequentialEventToQuantizedAbjadContainerConverter._group_tuplet_indices(
                 tuplet_indices
             )
             for group in reversed(grouped_tuplet_indices):
                 if len(group) > 1:
-                    FastSequentialEventToQuantizedAbjadContainerConverter._concatenate_adjacent_tuplets_for_one_group(
+                    RMakersSequentialEventToQuantizedAbjadContainerConverter._concatenate_adjacent_tuplets_for_one_group(
                         bar, group
                     )
 
@@ -649,8 +637,8 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
         return voice
 
     def _get_data_for_leaf(
-        self, indices: typing.Tuple[int, ...], leaf: abjad.Leaf
-    ) -> typing.Tuple[typing.Tuple[int, ...], bool, bool]:
+        self, indices: tuple[int, ...], leaf: abjad.Leaf
+    ) -> tuple[tuple[int, ...], bool, bool]:
         has_tie = abjad.get.indicator(leaf, abjad.Tie())
         is_rest = (
             isinstance(leaf, abjad.Rest)
@@ -661,9 +649,9 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
 
     def _get_data_for_tuplet_or_leaf(
         self,
-        indices: typing.Tuple[int, ...],
+        indices: tuple[int, ...],
         leaf_or_tuplet: typing.Union[abjad.Leaf, abjad.Tuplet],
-    ) -> typing.Tuple[typing.Tuple[typing.Tuple[int, ...], bool], ...]:
+    ) -> tuple[tuple[tuple[int, ...], bool], ...]:
         if isinstance(leaf_or_tuplet, abjad.Leaf):
             return (self._get_data_for_leaf(indices, leaf_or_tuplet),)
         else:
@@ -680,7 +668,7 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
 
     def _make_related_abjad_leaves_per_simple_event(
         self, voice: abjad.Voice
-    ) -> typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...]:
+    ) -> tuple[tuple[tuple[int, ...], ...], ...]:
         data_per_tuplet_or_leaf = []
         for nth_bar, bar in enumerate(voice):
             for nth_leaf_or_tuplet, leaf_or_tuplet in enumerate(bar):
@@ -714,10 +702,7 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
 
     def convert(
         self, sequential_event_to_convert: events.basic.SequentialEvent
-    ) -> typing.Tuple[
-        abjad.Container,
-        typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...],
-    ]:
+    ) -> tuple[abjad.Container, tuple[tuple[tuple[int, ...], ...], ...],]:
         voice = self._make_voice(sequential_event_to_convert)
         related_abjad_leaves_per_simple_event = (
             self._make_related_abjad_leaves_per_simple_event(voice)
@@ -725,37 +710,15 @@ class FastSequentialEventToQuantizedAbjadContainerConverter(
         return voice, related_abjad_leaves_per_simple_event
 
 
-class ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
-    ComplexSequentialEventToQuantizedAbjadContainerConverter
-):
-    """Quantize :class:`~mutwo.events.basic.SequentialEvent` objects via :mod:`abjadext.nauert`.
+class _DurationLineBasedQuantizedAbjadContainerMixin(object):
+    """Mixin for duration-line based quantization.
 
-    :param time_signatures: Set time signatures to divide the quantized abjad data
-        in desired bar sizes. If the converted :class:`~mutwo.events.basic.SequentialEvent`
-        is longer than the sum of all passed time signatures, the last time signature
-        will be repeated for the remaining bars.
-    :param duration_unit: This defines the `duration_unit` of the passed
-        :class:`~mutwo.events.basic.SequentialEvent` (how the
-        :attr:`~mutwo.events.abc.Event.duration` attribute will be
-        interpreted). Can either be 'beats' (default) or 'miliseconds'.
-    :param tempo_envelope: Defines the tempo of the converted music. This is an
-        :class:`expenvelope.Envelope` object which durations are beats and which
-        levels are either numbers (that will be interpreted as beats per minute ('BPM'))
-        or :class:`~mutwo.parameters.tempos.TempoPoint` objects. If no tempo envelope has
-        been defined, Mutwo will assume a constant tempo of 1/4 = 120 BPM.
-    :param attack_point_optimizer: Optionally the user can pass a
-        :class:`nauert.AttackPointOptimizer` object. Attack point optimizer help to
-        split events and tie them for better looking notation. The default attack point
-        optimizer is :class:`nauert.MeasurewiseAttackPointOptimizer` which splits events
-        to better represent metrical structures within bars. If no optimizer is desired
-        this argument can be set to ``None``.
     :param duration_line_minimum_length: The minimum length of a duration line.
     :type duration_line_minimum_length: int
     :param duration_line_thickness: The thickness of a duration line.
     :type duration_line_thickness: int
 
-    This converter differs from
-    :class:`SequentialEventToQuantizedAbjadContainerConverter` through
+    This converter differs from its parent class through
     the usage of duration lines for indicating rhythm instead of using
     flags, beams, dots and note head colors.
 
@@ -770,7 +733,7 @@ class ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
     >>> from mutwo.converters.frontends import abjad as mutwo_abjad
     >>> from mutwo.events import basic, music
     >>> converter = frontends.abjad.SequentialEventToAbjadVoiceConverter(
-    >>>     frontends.abjad.ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
+    >>>     frontends.abjad.RMakersSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
     >>>        )
     >>>    )
     >>> sequential_event_to_convert = basic.SequentialEvent(
@@ -782,28 +745,22 @@ class ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
 
     def __init__(
         self,
-        time_signatures: typing.Sequence[abjad.TimeSignature] = (
-            abjad.TimeSignature((4, 4)),
-        ),
-        duration_unit: str = "beats",  # for future: typing.Literal["beats", "miliseconds"]
-        tempo_envelope: expenvelope.Envelope = None,
-        attack_point_optimizer: typing.Optional[
-            nauert.AttackPointOptimizer
-        ] = nauert.MeasurewiseAttackPointOptimizer(),
-        search_tree: typing.Optional[nauert.SearchTree] = None,
+        *,
         duration_line_minimum_length: int = 6,
         duration_line_thickness: int = 3,
     ):
-        super().__init__(
-            time_signatures,
-            duration_unit,
-            tempo_envelope,
-            attack_point_optimizer,
-            search_tree,
-        )
         self._duration_line_minimum_length = duration_line_minimum_length
         self._duration_line_thickness = duration_line_thickness
 
+    @classmethod
+    def _set_docs(cls, parent: type):
+        doc_base = parent.__doc__.split("\n\n")
+        doc_mixin = _DurationLineBasedQuantizedAbjadContainerMixin.__doc__.split("\n\n")
+
+        cls.__doc__ = "\n\n".join(
+            [doc_base[0], doc_base[1] + "\n" + doc_mixin[1]] + doc_mixin[2:]
+        )
+
     def _prepare_first_element(self, first_element: abjad.Leaf):
         # don't write rests (simply write empty space)
         abjad.attach(abjad.LilyPondLiteral("\\omit Staff.Rest"), first_element)
@@ -847,9 +804,7 @@ class ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
     def _adjust_quantisized_abjad_leaves(
         self,
         quanitisized_abjad_leaves: abjad.Container,
-        related_abjad_leaves_per_simple_event: typing.Tuple[
-            typing.Tuple[typing.Tuple[int, ...], ...], ...
-        ],
+        related_abjad_leaves_per_simple_event: tuple[tuple[tuple[int, ...], ...], ...],
     ):
         is_first = True
 
@@ -881,12 +836,28 @@ class ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
                             abjad.Skip(element.written_duration),
                         )
 
+
+class NauertSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
+    NauertSequentialEventToQuantizedAbjadContainerConverter,
+    _DurationLineBasedQuantizedAbjadContainerMixin,
+):
+    def __init__(
+        self,
+        *args,
+        duration_line_minimum_length: int = 6,
+        duration_line_thickness: int = 3,
+        **kwargs,
+    ):
+        super().__init__(*args, **kwargs)
+        _DurationLineBasedQuantizedAbjadContainerMixin.__init__(
+            self,
+            duration_line_minimum_length=duration_line_minimum_length,
+            duration_line_thickness=duration_line_thickness,
+        )
+
     def convert(
         self, sequential_event_to_convert: events.basic.SequentialEvent
-    ) -> typing.Tuple[
-        abjad.Container,
-        typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...],
-    ]:
+    ) -> tuple[abjad.Container, tuple[tuple[tuple[int, ...], ...], ...],]:
 
         (
             quanitisized_abjad_leaves,
@@ -900,61 +871,10 @@ class ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
         return quanitisized_abjad_leaves, related_abjad_leaves_per_simple_event
 
 
-class FastSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
-    FastSequentialEventToQuantizedAbjadContainerConverter
+class RMakersSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
+    RMakersSequentialEventToQuantizedAbjadContainerConverter,
+    _DurationLineBasedQuantizedAbjadContainerMixin,
 ):
-    """Quantize :class:`~mutwo.events.basic.SequentialEvent` objects via :mod:`abjadext.nauert`.
-
-    :param time_signatures: Set time signatures to divide the quantized abjad data
-        in desired bar sizes. If the converted :class:`~mutwo.events.basic.SequentialEvent`
-        is longer than the sum of all passed time signatures, the last time signature
-        will be repeated for the remaining bars.
-    :param duration_unit: This defines the `duration_unit` of the passed
-        :class:`~mutwo.events.basic.SequentialEvent` (how the
-        :attr:`~mutwo.events.abc.Event.duration` attribute will be
-        interpreted). Can either be 'beats' (default) or 'miliseconds'.
-    :param tempo_envelope: Defines the tempo of the converted music. This is an
-        :class:`expenvelope.Envelope` object which durations are beats and which
-        levels are either numbers (that will be interpreted as beats per minute ('BPM'))
-        or :class:`~mutwo.parameters.tempos.TempoPoint` objects. If no tempo envelope has
-        been defined, Mutwo will assume a constant tempo of 1/4 = 120 BPM.
-    :param attack_point_optimizer: Optionally the user can pass a
-        :class:`nauert.AttackPointOptimizer` object. Attack point optimizer help to
-        split events and tie them for better looking notation. The default attack point
-        optimizer is :class:`nauert.MeasurewiseAttackPointOptimizer` which splits events
-        to better represent metrical structures within bars. If no optimizer is desired
-        this argument can be set to ``None``.
-    :param duration_line_minimum_length: The minimum length of a duration line.
-    :type duration_line_minimum_length: int
-    :param duration_line_thickness: The thickness of a duration line.
-    :type duration_line_thickness: int
-
-    This converter differs from
-    :class:`SequentialEventToQuantizedAbjadContainerConverter` through
-    the usage of duration lines for indicating rhythm instead of using
-    flags, beams, dots and note head colors.
-
-    **Note**:
-
-    Don't forget to add the 'Duration_line_engraver' to the resulting
-    abjad Voice, otherwise Lilypond won't be able to render the desired output.
-
-    **Example:**
-
-    >>> import abjad
-    >>> from mutwo.converters.frontends import abjad as mutwo_abjad
-    >>> from mutwo.events import basic, music
-    >>> converter = frontends.abjad.SequentialEventToAbjadVoiceConverter(
-    >>>     frontends.abjad.ComplexSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
-    >>>        )
-    >>>    )
-    >>> sequential_event_to_convert = basic.SequentialEvent(
-    >>>     [music.NoteLike("c", 0.125), music.NoteLike("d", 1), music.NoteLike([], 0.125), music.NoteLike("e", 0.16666), music.NoteLike("e", 0.08333333333333333)]
-    >>>    )
-    >>> converted_sequential_event = converter.convert(sequential_event_to_convert)
-    >>> converted_sequential_event.consists_commands.append("Duration_line_engraver")
-    """
-
     def __init__(
         self,
         *args,
@@ -963,92 +883,15 @@ class FastSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
         **kwargs,
     ):
         super().__init__(*args, **kwargs)
-        self._duration_line_minimum_length = duration_line_minimum_length
-        self._duration_line_thickness = duration_line_thickness
-
-    def _prepare_first_element(self, first_element: abjad.Leaf):
-        # don't write rests (simply write empty space)
-        abjad.attach(abjad.LilyPondLiteral("\\omit Staff.Rest"), first_element)
-        abjad.attach(
-            abjad.LilyPondLiteral("\\omit Staff.MultiMeasureRest"), first_element
+        _DurationLineBasedQuantizedAbjadContainerMixin.__init__(
+            self,
+            duration_line_thickness=duration_line_thickness,
+            duration_line_minimum_length=duration_line_minimum_length,
         )
-        # don't write stems (Rhythm get defined by duration line)
-        abjad.attach(abjad.LilyPondLiteral("\\omit Staff.Stem"), first_element)
-        # don't write flags (Rhythm get defined by duration line)
-        abjad.attach(abjad.LilyPondLiteral("\\omit Staff.Flag"), first_element)
-        # don't write beams (Rhythm get defined by duration line)
-        abjad.attach(abjad.LilyPondLiteral("\\omit Staff.Beam"), first_element)
-        # don't write dots (Rhythm get defined by duration line)
-        abjad.attach(
-            abjad.LilyPondLiteral("\\override Staff.Dots.dot-count = #0"),
-            first_element,
-        )
-        # only write black note heads (Rhythm get defined by duration line)
-        abjad.attach(
-            abjad.LilyPondLiteral("\\override Staff.NoteHead.duration-log = 2"),
-            first_element,
-        )
-        # set duration line properties
-        abjad.attach(
-            abjad.LilyPondLiteral(
-                "\\override Staff.DurationLine.minimum-length = {}".format(
-                    self._duration_line_minimum_length
-                )
-            ),
-            first_element,
-        )
-        abjad.attach(
-            abjad.LilyPondLiteral(
-                "\\override Staff.DurationLine.thickness = {}".format(
-                    self._duration_line_thickness
-                )
-            ),
-            first_element,
-        )
-
-    def _adjust_quantisized_abjad_leaves(
-        self,
-        quanitisized_abjad_leaves: abjad.Container,
-        related_abjad_leaves_per_simple_event: typing.Tuple[
-            typing.Tuple[typing.Tuple[int, ...], ...], ...
-        ],
-    ):
-        is_first = True
-
-        for abjad_leaves_indices in related_abjad_leaves_per_simple_event:
-            if abjad_leaves_indices:
-                first_element = tools.get_nested_item_from_indices(
-                    abjad_leaves_indices[0], quanitisized_abjad_leaves
-                )
-                if is_first:
-                    self._prepare_first_element(first_element)
-                    is_first = False
-
-                is_active = bool(abjad.get.pitches(first_element))
-                if is_active:
-                    if len(abjad_leaves_indices) > 1:
-                        abjad.detach(abjad.Tie(), first_element)
-
-                    abjad.attach(
-                        abjad.LilyPondLiteral("\\-", format_slot="after"), first_element
-                    )
-
-                    for indices in abjad_leaves_indices[1:]:
-                        element = tools.get_nested_item_from_indices(
-                            indices, quanitisized_abjad_leaves
-                        )
-                        tools.set_nested_item_from_indices(
-                            indices,
-                            quanitisized_abjad_leaves,
-                            abjad.Skip(element.written_duration),
-                        )
 
     def convert(
         self, sequential_event_to_convert: events.basic.SequentialEvent
-    ) -> typing.Tuple[
-        abjad.Container,
-        typing.Tuple[typing.Tuple[typing.Tuple[int, ...], ...], ...],
-    ]:
+    ) -> tuple[abjad.Container, tuple[tuple[tuple[int, ...], ...], ...],]:
 
         (
             quanitisized_abjad_leaves,
@@ -1070,3 +913,11 @@ class FastSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
             quanitisized_abjad_leaves,
             post_processed_releated_abjad_leaves_per_simple_event,
         )
+
+
+NauertSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter._set_docs(
+    NauertSequentialEventToQuantizedAbjadContainerConverter
+)
+RMakersSequentialEventToDurationLineBasedQuantizedAbjadContainerConverter._set_docs(
+    RMakersSequentialEventToQuantizedAbjadContainerConverter
+)
