@@ -15,17 +15,36 @@ class DynamicChoice(object):
     """Weighted random choices with dynamically changing weights.
 
     :param values: The items to choose from.
-    :type values: typing.Iterable[typing.Any]
+    :type values: typing.Sequence[typing.Any]
     :param curves: The dynamically changing weight for each value.
-    :type curves: typing.Iterable[expenvelope.Envelope]
+    :type curves: typing.Sequence[expenvelope.Envelope]
     :param random_seed: The seed which shall be set at class initialisation.
     :type random_seed: int
+
+    **Example:**
+
+    >>> import expenvelope
+    >>> from mutwo.generators import generic
+    >>> dynamic_choice = generic.DynamicChoice(
+    >>>    [0, 1, 2],
+    >>>    [
+    >>>        expenvelope.Envelope.from_points((0, 0), (0.5, 1), (1, 0)),
+    >>>        expenvelope.Envelope.from_points((0, 0.5), (0.5, 0), (1, 0.5)),
+    >>>        expenvelope.Envelope.from_points((0, 0.5), (1, 1)),
+    >>>    ],
+    >>> )
+    >>> dynamic_choice.gamble_at(0.3)
+    2
+    >>> dynamic_choice.gamble_at(0.3)
+    2
+    >>> dynamic_choice.gamble_at(0.3)
+    0
     """
 
     def __init__(
         self,
-        values: typing.Iterable[typing.Any],
-        curves: typing.Iterable[expenvelope.Envelope],
+        values: typing.Sequence[typing.Any],
+        curves: typing.Sequence[expenvelope.Envelope],
         random_seed: int = 100,
     ):
 
@@ -38,7 +57,7 @@ class DynamicChoice(object):
     def __repr__(self) -> str:
         return f"{type(self).__name__}({self._values})"
 
-    def items(self) -> typing.Tuple[typing.Tuple[typing.Any, expenvelope.Envelope]]:
+    def items(self) -> tuple[tuple[typing.Any, expenvelope.Envelope]]:
         return tuple(zip(self._values, self._curves))
 
     def gamble_at(self, time: numbers.Real) -> typing.Any:
@@ -46,6 +65,7 @@ class DynamicChoice(object):
 
         :param time: At which position on the x-Axis shall be gambled.
         :type time: numbers.Real
+        :return: The chosen value.
         """
         weights = [curve.value_at(time) for curve in self._curves]
         return self._random.choice(
